==> aws-java-sdk-1.3.4-sources.jar: com/amazonaws/services/simpleworkflow/model/transform/DomainConfigurationJsonUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleworkflow.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.simpleworkflow.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import org.codehaus.jackson.JsonToken;
import static org.codehaus.jackson.JsonToken.*;

/**
 * Domain Configuration JSON Unmarshaller
 */
public class DomainConfigurationJsonUnmarshaller implements Unmarshaller<DomainConfiguration, JsonUnmarshallerContext> {

    

    public DomainConfiguration unmarshall(JsonUnmarshallerContext context) throws Exception {
        DomainConfiguration domainConfiguration = new DomainConfiguration();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();

        while (true) {
            if (token == null) return domainConfiguration;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("workflowExecutionRetentionPeriodInDays", targetDepth)) {
                    context.nextToken();
                    domainConfiguration.setWorkflowExecutionRetentionPeriodInDays(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getCurrentDepth() <= originalDepth) {
                    return domainConfiguration;
                }
            }
            token = context.nextToken();
        }
    }

    private static DomainConfigurationJsonUnmarshaller instance;
    public static DomainConfigurationJsonUnmarshaller getInstance() {
        if (instance == null) instance = new DomainConfigurationJsonUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.3.10-sources.jar: com/amazonaws/services/simpleworkflow/model/transform/DomainConfigurationJsonUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleworkflow.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.simpleworkflow.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import org.codehaus.jackson.JsonToken;
import static org.codehaus.jackson.JsonToken.*;

/**
 * Domain Configuration JSON Unmarshaller
 */
public class DomainConfigurationJsonUnmarshaller implements Unmarshaller<DomainConfiguration, JsonUnmarshallerContext> {

    

    public DomainConfiguration unmarshall(JsonUnmarshallerContext context) throws Exception {
        DomainConfiguration domainConfiguration = new DomainConfiguration();

        
        
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("workflowExecutionRetentionPeriodInDays", targetDepth)) {
                    context.nextToken();
                    domainConfiguration.setWorkflowExecutionRetentionPeriodInDays(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getCurrentDepth() <= originalDepth) break;
            }
            token = context.nextToken();
        }
        
        return domainConfiguration;
    }

    private static DomainConfigurationJsonUnmarshaller instance;
    public static DomainConfigurationJsonUnmarshaller getInstance() {
        if (instance == null) instance = new DomainConfigurationJsonUnmarshaller();
        return instance;
    }
}
